@@ -16,10 +16,9 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program (see the file COPYING included with this
- *  distribution); if not, write to the Free Software Foundation, Inc.,
- *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /*
@@ -112,10 +111,12 @@ reliable_ack_packet_id_present(struct reliable_ack *ack, packet_id_type pid)
 {
     int i;
     for (i = 0; i < ack->len; ++i)
+    {
         if (ack->packet_id[i] == pid)
         {
             return true;
         }
+    }
     return false;
 }
 
@@ -242,7 +243,9 @@ reliable_ack_write(struct reliable_ack *ack,
         ASSERT(session_id_defined(sid));
         ASSERT(session_id_write(sid, &sub));
         for (i = 0, j = n; j < ack->len; )
+        {
             ack->packet_id[i++] = ack->packet_id[j++];
+        }
         ack->len = i;
     }
 
@@ -802,6 +805,7 @@ reliable_debug_print(const struct reliable *rel, char *desc)
 
 #else  /* ifdef ENABLE_CRYPTO */
 static void
-dummy(void) {
+dummy(void)
+{
 }
 #endif /* ENABLE_CRYPTO */
